pub struct Dir(/* private fields */);Implementations
Sourceimpl Dir
impl Dir
Sourcepub fn new<P>(root: P) -> Result<Self>
pub fn new<P>(root: P) -> Result<Self>
Creates a new Dir instance.
If the root directory does not exist, it will be created.
Sourcepub fn new_readonly<P>(root: P) -> Self
pub fn new_readonly<P>(root: P) -> Self
Creates a new Dir without creating the root directory tree
pub fn path(&self) -> &Path
pub fn create_if_not_exists(&self) -> Result<()>
pub fn create_dir_all<P: AsRef<Path>>(&self, rel_path: P) -> Result<()>
pub fn remove_file<P: AsRef<Path>>(&self, rel_path: P) -> Result<()>
pub fn file<P: AsRef<Path>>(&self, rel_path: P) -> FileBuilder
pub fn unnamed_file(&self) -> UnnamedFileBuilder
Sourcepub fn subdir_readonly<P: AsRef<Path>>(&self, rel_path: P) -> Self
pub fn subdir_readonly<P: AsRef<Path>>(&self, rel_path: P) -> Self
Creates Dir instance for a subdirectory of the current one.
Note: The subdirectory will not be created if it does not exist.
Use create_subdir to create it.
Sourcepub fn create_subdir<P: AsRef<Path>>(&self, rel_path: P) -> Result<Self>
pub fn create_subdir<P: AsRef<Path>>(&self, rel_path: P) -> Result<Self>
Creates Dir instance for a subdirectory of the current one.
The subdirectory will be created if it does not exist.
pub fn file_exists<P: AsRef<Path>>(&self, rel_path: P) -> bool
pub fn entries(&self) -> Result<ReadDir>